<?php

namespace App\Controller;

use App\Repository\PostRepository;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\Routing\Attribute\Route;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use App\Entity\Post;
use App\Form\PostType;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Component\Security\Http\Attribute\IsGranted;

class PostController extends AbstractController
{
    #[Route('/', name: 'app_posts')]
    public function index(PostRepository $repository): Response
    {
        $posts = $repository->findAll();
        return $this->render('post/index.html.twig', [
            'posts' => $posts,
        ]);
    }

    #[Route('/posts/add', name: 'app_add_posts')]
    #[IsGranted('ROLE_USER', message: 'You must be logged in to access this page.')]
    public function new(Request $request, EntityManagerInterface $entityManager): Response
    {
        $post = new Post();

        $form = $this->createForm(PostType::class, $post);

        $form->handleRequest($request);
        //dd($form); 
        if ($form->isSubmitted() && $form->isValid()) {
            $post = $form->getData();
            $post->setPublicationDate(new \DateTimeImmutable("now"));
            
            $entityManager->persist($post);
            $entityManager->flush();

            return $this->redirectToRoute('app_add_posts');
        }

        return $this->render('post/post.html.twig', [
            'form' => $form, //->createView(),
        ]);
    }
}
